@@ -61,14 +61,28 @@ sebie_update_view(struct sebie_s *sebie)
   
   if (sebie->dirty_tags & SEBIE_UPDATE_SELECTION_FAC) {
     gchar buf[6];
-    snprintf(buf, 6, "%5d", sebie->model.selection_fac_width);
-    gtk_entry_set_text(GTK_ENTRY(sebie->view.entry_selection_fac_width), buf);
-    snprintf(buf, 6, "%5d", sebie->model.selection_fac_height);
-    gtk_entry_set_text(GTK_ENTRY(sebie->view.entry_selection_fac_height), buf);
     sebie->model.selection_fac = (double)sebie->model.selection_fac_width / (double) sebie->model.selection_fac_height;
     snprintf(buf, 6, "%5.2f", sebie->model.selection_fac);
     gtk_label_set_text(GTK_LABEL(sebie->view.label_selection_fac), buf);
   }
+  
+  if (sebie->dirty_tags & SEBIE_UPDATE_SELECTION_FAC_W) {
+    gchar buf[6];
+    snprintf(buf, 6, "%d", sebie->model.selection_fac_width);
+    gtk_entry_set_text(GTK_ENTRY(sebie->view.entry_selection_fac_width), buf);
+  }
+
+  if (sebie->dirty_tags & SEBIE_UPDATE_SELECTION_FAC_H) {
+    gchar buf[6];
+    snprintf(buf, 6, "%d", sebie->model.selection_fac_height);
+    gtk_entry_set_text(GTK_ENTRY(sebie->view.entry_selection_fac_height), buf);
+  }
+
+  if (sebie->dirty_tags & SEBIE_UPDATE_IMAGE_GAMMA) {
+    gchar buf[6];
+    snprintf(buf, 6, "%1.1f", sebie->model.image_gamma);
+    gtk_entry_set_text(GTK_ENTRY(sebie->view.entry_selection_gamma), buf);
+  }
 
   if (sebie->dirty_tags & SEBIE_UPDATE_SELECTION_RECT) {
     GdkGC *gdkGC = gdk_gc_new(sebie->view.drawingarea1->window);
@@ -209,14 +223,19 @@ load_pixbuf (struct sebie_s *sebie)
   printf("scaled: width: %d height: %d \n",
 	 sebie->model.scaled_width, 
 	 sebie->model.scaled_height);
+  if (sebie->model.scaled_pixbuf_orig != NULL) {
+    g_object_unref(sebie->model.scaled_pixbuf_orig);
+  }
   if (sebie->model.scaled_pixbuf != NULL) {
     g_object_unref(sebie->model.scaled_pixbuf);
   }
-  sebie->model.scaled_pixbuf = gdk_pixbuf_scale_simple(sebie->model.image_pixbuf,
-						       sebie->model.scaled_width,
-						       sebie->model.scaled_height,
-						       GDK_INTERP_HYPER);
+  sebie->model.scaled_pixbuf_orig = gdk_pixbuf_scale_simple(sebie->model.image_pixbuf,
+							    sebie->model.scaled_width,
+							    sebie->model.scaled_height,
+							    GDK_INTERP_HYPER);
+  sebie->model.scaled_pixbuf = pixbuf_color_corrections(sebie->model.scaled_pixbuf_orig, sebie->model.image_gamma);
   sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
+  sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
 #if 0
   sebie_update_view(sebie);
 #endif
@@ -260,11 +279,38 @@ rotate_scaled(struct sebie_s *sebie, int direction)
     sebie->model.scaled_pixbuf = rotated;
   
     sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
+    sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
     sebie_update_view(sebie);
   }
 }
 
 
+void
+apply_gamma(struct sebie_s *sebie)
+{
+  GdkPixbuf *corr = pixbuf_color_corrections(sebie->model.scaled_pixbuf_orig,
+					     sebie->model.image_gamma);
+
+  if (sebie->model.scaled_pixbuf != NULL) {
+    g_object_unref(sebie->model.scaled_pixbuf);
+  }
+  
+  if (sebie->model.scaled_rotation == SEBIE_ROTATE_000) {
+    sebie->model.scaled_pixbuf = corr;
+  } else {
+    GdkPixbuf *rotated = rotate_pixbuf(corr, sebie->model.scaled_rotation);
+    if (corr != NULL) {
+      g_object_unref(corr);
+    }
+    sebie->model.scaled_pixbuf = rotated;
+  }
+  
+  sebie->dirty_tags |= SEBIE_UPDATE_SCALED_PIXBUF;
+  sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_RECT;
+  sebie_update_view(sebie);
+}
+
+
 void
 save_sebie_config(struct sebie_s *sebie)
 {
@@ -273,9 +319,11 @@ save_sebie_config(struct sebie_s *sebie)
       { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "" },
       { "InputRegEx", CONFIG_STRING, &sebie->model.input_regex, "\\([0-9]*\\).jpg" },
       { "OutputFormat", CONFIG_STRING, &sebie->model.output_format, "Image%s.jpg" },
+      { "ImageOutputWidth",  CONFIG_INTEGER, &sebie->model.selection_fac_width, 1024},
+      { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
+      { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
       { NULL, CONFIG_END, NULL, 0}
     };
-  
     sebie_write_config(sebie->config_file, config_spec);
     sebie->model_tags = 0;
   }
@@ -299,6 +347,9 @@ init_sebie_model(struct sebie_s *sebie)
     { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "" },
     { "InputRegEx", CONFIG_STRING, &sebie->model.input_regex, "\\([0-9]*\\).jpg" },
     { "OutputFormat", CONFIG_STRING, &sebie->model.output_format, "Image%s.jpg" },
+    { "ImageOutputWidth",  CONFIG_INTEGER, &sebie->model.selection_fac_width, 1024},
+    { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
+    { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
     { NULL, CONFIG_END, NULL, 0}
   };
   
@@ -313,14 +364,15 @@ init_sebie_model(struct sebie_s *sebie)
 
   sebie->model.file_list = gtk_list_store_new(1, G_TYPE_STRING);
   
-  sebie->model.selection_fac_width = 1024;
-  sebie->model.selection_fac_height = 768;
-  sebie->model.selection_fac = 1024.0 / 768.0;
+  sebie->model.selection_fac = sebie->model.selection_fac_width / sebie->model.selection_fac_height;
 
   sebie->model.mouse_click_type = SEBIE_NOT_CLICKED;
   
   sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC;
-
+  sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC_W;
+  sebie->dirty_tags |= SEBIE_UPDATE_SELECTION_FAC_H;
+  sebie->dirty_tags |= SEBIE_UPDATE_IMAGE_GAMMA;
+  
   sebie->model.statusbar_text = strdup("   SeBIE  (C) 2003 by Peter.Seiderer@ciselant.de");
   sebie->dirty_tags |= SEBIE_UPDATE_STATUS_BAR;
 }
@@ -331,7 +383,7 @@ int main(int argc, char *argv[])
   GtkWidget *window1;
   struct sebie_s *sebie;
   
-  sebie = g_new(struct sebie_s, 1);
+  sebie = g_new0(struct sebie_s, 1);
 
   gtk_set_locale ();
 
