@@ -55,10 +55,22 @@ void
 on_button_rotate_right_clicked (GtkButton *button,
 				gpointer  user_data);
 
+void
+on_entry_selection_fac_width_changed (GtkEditable *editable,
+				      gpointer  user_data);
+
+void
+on_entry_selection_fac_height_changed (GtkEditable *editable,
+				       gpointer  user_data);
+
 void
 on_button_fac_swap (GtkButton *button,
 		    gpointer  user_data);
 
+void
+on_entry_selection_gamma_changed (GtkEditable *editable,
+				  gpointer  user_data);
+
 gboolean
 on_drawingarea1_button_press_event     (GtkWidget       *widget,
                                         GdkEventButton  *event,
