@@ -18,6 +18,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
+#include "config.h"
 #include "sebie_view.h"
 #include "sebie_callbacks.h"
 
@@ -36,7 +37,8 @@ init_sebie_view(struct sebie_s *sebie)
   GtkWidget *tmp_toolbar_icon;
   
   sebie->view.window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title (GTK_WINDOW (sebie->view.window1), _("window1"));
+  gchar * window1_title = "SeBIE " PACKAGE_VERSION ;
+  gtk_window_set_title (GTK_WINDOW (sebie->view.window1), window1_title);
   
   sebie->view.vbox1 = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (sebie->view.vbox1);
@@ -123,12 +125,22 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_label_set_use_underline (GTK_LABEL (((GtkToolbarChild*) (g_list_last (GTK_TOOLBAR (sebie->view.toolbar1)->children)->data))->label), TRUE);
   gtk_widget_show (sebie->view.button_rotate_right);
 
+  sebie->view.label_selection_fac_width = gtk_label_new (_(" w:"));
+  gtk_widget_show (sebie->view.label_selection_fac_width);
+  gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.label_selection_fac_width, NULL, NULL);
+  gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_fac_width), GTK_JUSTIFY_LEFT);
+
   sebie->view.entry_selection_fac_width = gtk_entry_new ();
   gtk_widget_show (sebie->view.entry_selection_fac_width);
   gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.entry_selection_fac_width, NULL, NULL);
   gtk_widget_set_size_request (sebie->view.entry_selection_fac_width, 50, 20);
   gtk_entry_set_max_length (GTK_ENTRY (sebie->view.entry_selection_fac_width), 5);
   
+  sebie->view.label_selection_fac_height = gtk_label_new (_(" h:"));
+  gtk_widget_show (sebie->view.label_selection_fac_height);
+  gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.label_selection_fac_height, NULL, NULL);
+  gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_fac_height), GTK_JUSTIFY_LEFT);
+
   sebie->view.entry_selection_fac_height = gtk_entry_new ();
   gtk_widget_show (sebie->view.entry_selection_fac_height);
   gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.entry_selection_fac_height, NULL, NULL);
@@ -154,6 +166,17 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.label_selection_fac, NULL, NULL);
   gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_fac), GTK_JUSTIFY_LEFT);
 
+  sebie->view.label_selection_gamma = gtk_label_new (_(" gamma:"));
+  gtk_widget_show (sebie->view.label_selection_gamma);
+  gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.label_selection_gamma, NULL, NULL);
+  gtk_label_set_justify (GTK_LABEL (sebie->view.label_selection_gamma), GTK_JUSTIFY_LEFT);
+
+  sebie->view.entry_selection_gamma = gtk_entry_new ();
+  gtk_widget_show (sebie->view.entry_selection_gamma);
+  gtk_toolbar_append_widget (GTK_TOOLBAR (sebie->view.toolbar1), sebie->view.entry_selection_gamma, NULL, NULL);
+  gtk_widget_set_size_request (sebie->view.entry_selection_gamma, 50, 20);
+  gtk_entry_set_max_length (GTK_ENTRY (sebie->view.entry_selection_gamma), 5);
+
 #if 0
   sebie->view.button7 = gtk_toolbar_append_element (GTK_TOOLBAR (sebie->view.toolbar1),
                                 GTK_TOOLBAR_CHILD_BUTTON,
@@ -271,7 +294,16 @@ init_sebie_view(struct sebie_s *sebie)
   g_signal_connect ((gpointer) sebie->view.drawingarea1, "motion_notify_event",
                     G_CALLBACK (on_drawingarea1_motion_notify_event),
                     sebie);
-  
+  g_signal_connect ((gpointer) sebie->view.entry_selection_fac_width, "changed",
+                    G_CALLBACK (on_entry_selection_fac_width_changed),
+                    sebie);
+  g_signal_connect ((gpointer) sebie->view.entry_selection_fac_height, "changed",
+                    G_CALLBACK (on_entry_selection_fac_height_changed),
+                    sebie);
+  g_signal_connect ((gpointer) sebie->view.entry_selection_gamma, "changed",
+                    G_CALLBACK (on_entry_selection_gamma_changed),
+                    sebie);
+
   gtk_widget_set_events (sebie->view.drawingarea1, GDK_EXPOSURE_MASK
 			 | GDK_LEAVE_NOTIFY_MASK
 			 | GDK_BUTTON_PRESS_MASK
